@@ -2,8 +2,8 @@ from .async_liqpay import AsyncLiqPay
 from .sync_liqpay import LiqPay
 
 
-__title__ = "asyncio LiqPay Python3 SDK"
-__version__ = "2.0.1"
+__title__ = 'asyncio LiqPay Python3 SDK'
+__version__ = '3.0.0'
 
 __all__ = [
     'AsyncLiqPay',
